package
module
Version:
v0.0.0-...-1ed2ef0
Opens a new window with list of versions in this module.
Published: Jan 29, 2024
License: GPL-3.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
Documentation
¶
type Interface interface {
Nodes() []Node
}
type Link interface {
NodeIndex() int
Weight() int
}
type Node interface {
Links() []Link
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.